@@ -84,6 +84,11 @@ def main():
     instance_name_parser.add_argument(
         "instance", metavar="INSTANCE_ID", help="Instance Name of the Minecraft Server")
 
+    reason_parser = ap.ArgumentParser(add_help=False)
+    reason_parser.add_argument(
+        "reason", nargs="+", help="Reason to be appended to the 'say' Command."
+    )
+
     parser_attach = subparsers.add_parser(
         "attach", parents=[instance_name_parser], help="Attach to the Console of the Instance")
 
@@ -98,7 +103,7 @@ def main():
 
     parser_exec = subparsers.add_parser(
         "exec", parents=[instance_name_parser], help="Execute a command in the Console of the Instance")
-    parser_exec.add_argument("command", metavar="COMMAND", nargs="+",
+    parser_exec.add_argument("command", nargs="+",
                              help="Command to execute")
 
     parser_export = subparsers.add_parser(
@@ -124,10 +129,10 @@ def main():
 
     parser_rename = subparsers.add_parser(
         "rename", parents=[instance_name_parser], help="Rename a Minecraft Server Instance")
-    parser_rename.add_argument("newName", metavar="NEW_NAME")
+    parser_rename.add_argument("new_name")
 
     parser_restart = subparsers.add_parser(
-        "restart", parents=[instance_name_parser], help="Restart a Minecraft Server Instance")
+        "restart", parents=[instance_name_parser, reason_parser], help="Restart a Minecraft Server Instance")
 
     parser_remove = subparsers.add_parser(
         "rm", parents=[instance_name_parser], help="Remove an Instance.")
@@ -146,7 +151,7 @@ def main():
                               help="Start even after Reboot")
 
     parser_stop = subparsers.add_parser(
-        "stop", parents=[instance_name_parser], help="Stop a Minecraft Server Instance")
+        "stop", parents=[instance_name_parser, reason_parser], help="Stop a Minecraft Server Instance")
     parser_stop.add_argument("-p", "--persistent", action='store_true',
                              help="Do not start again after Reboot")
 
@@ -159,6 +164,7 @@ def main():
         print("Must be root.")
         sys.exit(1)
 
+    # Starts Program as server_user
     user = settings.CFG_DICT['server_user']
     user_ids = proc.get_ids(user)
     proc.run_as(*user_ids)
@@ -209,21 +215,20 @@ def main():
             service.set_status(args.instance, "enable")
         try:
             service.set_status(args.instance, args.action)
-        except AssertionError:
+        except AssertionError as ex:
             print(ex)
 
     elif args.action == 'stop':
-        if args.persistent:
-            service.set_status(args.instance, "disable")
         try:
-            service.set_status(args.instance, args.action)
-        except AssertionError:
+            service.notified_stop(args.instance, args.reason, args.persistent)
+        except AssertionError as ex:
             print(ex)
 
     elif args.action == 'restart':
         try:
-            service.set_status(args.instance, args.action)
-        except AssertionError:
+            service.notified_stop(
+                args.instance, args.reason, restart=True)
+        except AssertionError as ex:
             print(ex)
 
     elif args.action == 'attach':
@@ -241,7 +246,7 @@ def main():
 
     elif args.action == 'rename':
         try:
-            common.rename(args.instance, args.newName)
+            common.rename(args.instance, args.new_name)
         except (AssertionError, FileExistsError) as ex:
             print("Unable to rename '{0}': {1}".format(
                 args.instance, str(ex).split(":")[0]))
