@@ -16,7 +16,9 @@
 # You should have received a copy of the GNU General Public License
 # along with mcctl. If not, see <http://www.gnu.org/licenses/>.
 
-from mcctl import web, storage, service, config, proc, status
+from socket import error as sock_error
+from mcstatus import MinecraftServer
+from mcctl import web, storage, service, config, proc
 
 
 def create(instance: str, source: str, memory: str, properties: list, start: bool):
@@ -36,7 +38,7 @@ def create(instance: str, source: str, memory: str, properties: list, start: boo
     assert not instance_path.exists(), "Instance already exists"
     storage.create_dirs(instance_path)
 
-    jar_path_src = web.pull(source)
+    jar_path_src, version = web.pull(source)
     jar_path_dest = instance_path / "server.jar"
     storage.copy(jar_path_src, jar_path_dest)
     proc.pre_start(jar_path_dest)
@@ -51,7 +53,7 @@ def create(instance: str, source: str, memory: str, properties: list, start: boo
             proc.run_as(0, 0)
             service.set_status(instance, "enable")
             service.set_status(instance, "start")
-            print("Configured and started.")
+            print("Configured and started with Version '{}'.".format(version))
     else:
         print("How can you not agree that tacos are tasty?!?")
         storage.remove(instance, confirm=False)
@@ -70,23 +72,30 @@ def get_instance_list(filter_str: str = ''):
     server_paths = base_path.iterdir()
     servers = [x.name for x in server_paths]
 
-    template = "%-15s%-20s%-12s%-12s"
+    template = "%-12s %-20s %-16s %-10s %-10s"
     title = template % (
-        "Name", "Server Version", "Status", "Persistent")
+        "Name", "Server Version", "Player Count", "Status", "Persistent")
 
     print(title)
     for name in servers:
         if filter_str in name:
             cfg = config.get_properties(base_path / name / "server.properties")
             port = int(cfg["server-port"])
-            mc_ping = status.MineStat('localhost', port)
 
-            version = mc_ping.version if not mc_ping.version is None else "n/a"
+            try:
+                server = MinecraftServer('localhost', port)
+                status = server.status()
+                online = status.players.online
+                version = status.version.name
+            except (ConnectionError, sock_error):
+                online = 0
+                version = "n/a"
+
             run_status = "Active" if service.is_active(name) else "Inactive"
             contents = template % (
-                name, version,
-                run_status,
-                service.is_enabled(name))
+                name, version, "{0}/{1}".format(online,
+                                                cfg["max-players"]),
+                run_status, service.is_enabled(name))
             print(contents)
 
 
@@ -117,14 +126,9 @@ def update(instance: str, new_type_id: str, literal_url: bool = False):
         new_type_id {str} -- The Type ID of the new minecraft server Jar.
     """
 
-    running = service.is_active(instance)
-    if running:
-        service.set_status(instance, "stop")
-
-    jar_src = web.pull(new_type_id, literal_url)
+    jar_src, version = web.pull(new_type_id, literal_url)
     jar_dest = storage.get_home_path() / "instances" / instance / "server.jar"
     storage.copy(jar_src, jar_dest)
 
-    if running:
-
-        service.set_status(instance, "start")
+    if service.is_active(instance):
+        service.notified_stop(instance, "Updating to Version {}".format(version), restart=True)
