@@ -39,23 +39,27 @@ def attach(instance: str):
 
     assert is_active(instance), "The Server is not running"
     cmd = shlex.split('screen -r mc-{}'.format(instance))
-    proc = sproc.Popen(cmd, preexec_fn=demote())
+    proc = sproc.Popen(cmd, preexec_fn=demote())  # nopep8 pylint: disable=subprocess-popen-preexec-fn
     proc.wait()
 
 
-def mc_exec(instance: str, command: list, timeout: int = 0.5):
+def mc_exec(instance: str, command: list, timeout: int = 0.1, retries: int = 20, flush_retries: int = 3):
     """Execute a command on the console of a server.
 
     Uses the 'stuff' command of screen to pass the minecraft command to the server.
     Return Values are read from 'latest.log' shortly after the command is executed.
-    The logfile is read every <timeout> seconds. If nothing is appended to the Log in this timespan, the function completes.
+    The logfile is read every <timeout> seconds. If nothing is appended to the Log after the set amount of <retries>,
+    the function exits. If there were already some lines received, the function tries <flush_retries> times before exiting.
+    Like this, the function will more likely give an output, and will exit faster.
 
     Arguments:
         instance {str} -- The name of the instance.
         command {list} -- A list of the individual parts of the command executed on the server console.
 
     Keyword Arguments:
-        timeout {int} -- The timeout interval between log reads. (default: {0.5})
+        timeout {int} -- The timeout interval between log reads. (default: {0.1})
+        retries {int} -- The amount of retries when no lines have been pushed to console. (default: {20})
+        flush_retries {int} -- The amount of retries when some lines have been pushed to console. (default: {3})
     """
 
     assert is_active(
@@ -63,25 +67,26 @@ def mc_exec(instance: str, command: list, timeout: int = 0.5):
 
     log_path = get_home_path() / "instances" / instance / "logs/latest.log"
 
-    old_count = 0
-    line_count = sum(1 for line in open(log_path))
+    file_hnd = open(log_path)
+    old_count = sum(1 for line in file_hnd) - 1
 
     jar_cmd = " ".join(command)
     cmd = shlex.split(
         'screen -p 0 -S mc-{0} -X stuff "{1}^M"'.format(instance, jar_cmd))
-    proc = sproc.Popen(cmd, preexec_fn=demote())
+    proc = sproc.Popen(cmd, preexec_fn=demote())  # nopep8 pylint: disable=subprocess-popen-preexec-fn
     proc.wait()
 
-    time.sleep(timeout)
-    while line_count > old_count:
+    i = 0
+    while i < retries:
+        i += 1
         time.sleep(timeout)
-        i = 0
-        with open(log_path) as log:
-            for i, line in enumerate(log):
-                if i >= line_count:
-                    print(line.rstrip())
-        old_count = line_count
-        line_count = i + 1
+        file_hnd.seek(0)
+        for j, line in enumerate(file_hnd):
+            if j > old_count:
+                i = retries - flush_retries
+                print(line.rstrip())
+                old_count += 1
+    file_hnd.close()
 
 
 def get_ids(user: str) -> tuple:
@@ -154,7 +159,7 @@ def pre_start(jar_path: Path, watch_file=None, kill_sec: int = 80) -> bool:
     """
 
     cmd = shlex.split('/bin/java -jar {}'.format(jar_path))
-    proc = sproc.Popen(cmd, cwd=jar_path.parent,
+    proc = sproc.Popen(cmd, cwd=jar_path.parent,  # pylint: disable=subprocess-popen-preexec-fn
                        preexec_fn=demote(), stdout=sproc.PIPE, stderr=sproc.PIPE)
 
     fps = 4
